@@ -24,7 +24,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *----------------------------------------------------------------------*/
 /*
-** $Id: xdefaults.c,v 1.139 2005/03/21 18:44:10 cvs Exp $
+** $Id: xdefaults.c,v 1.141 2005/06/20 20:31:03 cvs Exp $
 */
 
 #include "../config.h"
@@ -228,6 +228,7 @@ static const struct {
 #ifdef BACKGROUND_IMAGE
 	STRG(Rs_tabbarPixmap, "tabbarPixmap", "tbpixmap", "file[;geom]", "tabbar background image", 0),
 	BOOL(Rs_tabPixmap, "tabUsePixmap", "tupixmap", Opt_tabPixmap, "use tabbar background image for tabs", 0),
+	STRG(Rs_appIcon, "appIcon", "ic", "file[;geom]", "application icon file", 1),
 #endif	/* BACKGROUND_IMAGE */
 
 	BOOL(Rs_utmpInhibit, "utmpInhibit", "ut", Opt_utmpInhibit,
@@ -550,6 +551,8 @@ static const struct {
 		Opt2_disableHotkeys, "disabling all keyboard shortcuts", 0),
 	BOOL(Rs2_disableDefaultHotkeys, "disableDefaultHotkeys", "ddh",
 		Opt2_disableDefaultHotkeys, "disabling default keyboard shortcuts", 0),
+	BOOL(Rs2_linuxHomeEndKey, "linuxHomeEndKey", "lk",
+		Opt2_linuxHomeEndKey, "enable Linux console Home/End keys", 0),
 
 	STRG(Rs_modifier, "modifier", "mod", "modifier",
 		"meta modifier = alt|meta|hyper|super|mod1|...|mod5", 0),
